function[x,T,q_flux_in_Wcm2,dthabdt_cms]=Ablative_shield(N)

%EXAMPLE 1.5-1: Thermal Protection System for Atmospheric Entry
%
% Inputs:
% N: number of nodes in solution (-)
%
% Outputs:
% x: position of nodes (m)
% T: temperatures at nodes (K)
% q_flux_in_Wcm2: heat flux on air (W/cm^2)
% dthabdt_cms: rate of shield consumption (cm/s)

th_ab=0.05;  	%ablation shield thickness (m)
th_s=0.01;   	%steel thickness (m)
k_s=20;     	%steel conductivity (W/m-K)
q_flux=100*100^2; %heat flux (W/m^2)
T_m=755;    	%melting temperature (K)
DELTAi_fus_ab=200e3; 	%latent heat of fusion (J/kg)
h_bar=10;       	%heat transfer coefficient (W/m^2-K)
T_infinity=320;  	%internal air temperature (K)
rho_ab=1200;    	%density (kg/m^3)
A_c=1;      %per unit area of wall (m^2)

%setup nodes
DELTAx=th_ab/(N-1);  		%distance between nodes
for i=1:N 
    x(i,1)=th_ab*(i-1)/(N-1);	%position of each node
end

R_cond_s=th_s/(A_c*k_s); %conduction resistance of steel (K/W)
R_conv=1/(A_c*h_bar);     %convection resistance (K/W)
													
%initial guess for temperature distribution
for i=1:N
    Tg(i,1)=T_m+(T_infinity-T_m)*(i-1)/(N-1); %linear from melting to air (K)
end

%setup matrices
A=spalloc(N,N,3*N);
b=zeros(N,1);

err=999;       %initial value of error (K), must be larger than tol
tol = 0.01; %tolerance for convergence (K)
while(err>tol)
    %node 1
    A(1,1)=1;
    b(1,1)=T_m;

    %internal nodes
    for i=2:(N-1)
        A(i,i)=-k_ab((Tg(i)+Tg(i+1))/2)*A_c/DELTAx...
            -k_ab((Tg(i)+Tg(i-1))/2)*A_c/DELTAx;
        A(i,i+1)=k_ab((Tg(i)+Tg(i+1))/2)*A_c/DELTAx;
        A(i,i-1)=k_ab((Tg(i)+Tg(i-1))/2)*A_c/DELTAx;
    end

    %node N
    A(N,N)=-k_ab((Tg(N)+Tg(N-1))/2)*A_c/DELTAx-1/(R_cond_s+R_conv);
    A(N,N-1)=k_ab((Tg(N)+Tg(N-1))/2)*A_c/DELTAx;
    b(N,1)=-T_infinity/(R_cond_s+R_conv);

    X=A\b;     %solve matrix equation
    T=X;

    err=sqrt(sum((T-Tg).^2)/N) %compute rms error
    Tg=T;   %reset guess values used to setup A and b
end

q_flux_in=(T(N)-T_infinity)/(R_cond_s+R_conv)/A_c;   %heat flux to air (W/m^2)
q_flux_in_Wcm2=q_flux_in/100^2;     %heat flux to air (W/cm^2)
dthabdt=(q_flux-q_flux_in)/(DELTAi_fus_ab*rho_ab);    %rate of shield consumption (m/s)
dthabdt_cms=dthabdt*100; %rate of shield consumption (cm/s)


function[k]=k_ab(T)
 
%data from Table 5-1
Td=[300,350,400,450,500,550,600,650,700,755];
kd=[0.1,0.15,0.19,0.21,0.22,0.24,0.28,0.33,0.38,0.45];
k=interp1(Td,kd,T,'spline'); %interpolate data to obtain conductivity
